#include "component_return.h"

/* DEPENDENCIES: Physics */

/* Initializes return component. */
void 
component_return_init(ComponentReturn* self, f32 speed, f32 velocityMax, u32 lifetime, u32 senderID)
{
	self->speed = speed;
	self->velocityMax = velocityMax;
	self->lifetime = lifetime;
	self->senderID = senderID;
}

/* Ticks return component. */
/* Rapidly accelerates entity towards sender. */
void 
component_return_tick(ComponentReturn* self, ECS* ecs)
{
	f32 angle;
	ComponentPhysics* senderPhysics;
	ComponentPhysics* physics;

	if (self->lifetime > 0)
	{
		self->lifetime--;

		if (self->lifetime <= 0)
		{
			physics = ecs_component_get(ecs, ECS_COMPONENT_PHYSICS, self->id);
			
			physics->velocityMax = self->velocityMax;
		}

		return;
	}

	senderPhysics = ecs_component_get(ecs, ECS_COMPONENT_PHYSICS, self->senderID);
	physics = ecs_component_get(ecs, ECS_COMPONENT_PHYSICS, self->id);

	angle = ATAN(physics->position[0], senderPhysics->position[0], physics->position[1], senderPhysics->position[1]);

	physics->velocity[0] += cos(angle) * self->speed;
	physics->velocity[1] += sin(angle) * self->speed;
}
